Allow AI to receive tech gifts in tech cost style > 0

Per Inge Mathisen <per-0/[email protected]> Thu, 10 Mar 2005 20:00:16 +0000 (GMT)
Newsgroups gmane.games.freeciv.ai
Message-ID <[email protected]>
See $subject. I believe this has been mentioned before, but I don't
remember by whom. Committed.

  - Per
techstyle.diff (text/plain, 1.2 KB)
Index: ai/advdiplomacy.c
===================================================================
RCS file: /home/freeciv/CVS/freeciv/ai/advdiplomacy.c,v
retrieving revision 1.69
diff -u -r1.69 advdiplomacy.c
--- ai/advdiplomacy.c	10 Mar 2005 19:56:45 -0000	1.69
+++ ai/advdiplomacy.c	10 Mar 2005 19:59:28 -0000
@@ -552,13 +552,15 @@
     if (pclause->type != CLAUSE_GOLD && pclause->type != CLAUSE_MAP
         && pclause->type != CLAUSE_SEAMAP && pclause->type != CLAUSE_VISION
         && (pclause->type != CLAUSE_ADVANCE 
+            || game.rgame.tech_cost_style != 0
             || pclause->value == pplayer->ai.tech_goal
             || pclause->value == pplayer->research.researching
             || is_tech_a_req_for_goal(pplayer, pclause->value, 
                                       pplayer->ai.tech_goal))) {
       /* We accept the above list of clauses as gifts, even if we are
        * at war. We do not accept tech or cities since these can be used
        * against us, unless we know that we want this tech anyway. */
       only_gifts = FALSE;
     }
   } clause_list_iterate_end;
@@ -552,13 +552,15 @@
       /* We accept the above list of clauses as gifts, even if we are
        * at war. We do not accept tech or cities since these can be used
-       * against us, unless we know that we want this tech anyway. */
+       * against us, unless we know that we want this tech anyway, or
+       * it doesn't matter due to tech cost style. */
       only_gifts = FALSE;
     }